@@ -31,7 +31,7 @@ use Class::Inspector ();
 
 use vars qw{$VERSION $DEBUG};
 BEGIN {
-	$VERSION = '0.16';
+	$VERSION = '0.18';
 	$DEBUG   = !! $DEBUG;
 }
 
@@ -345,6 +345,26 @@ sub _params {
 	}
 }
 
+# Resolve the message list
+sub _messages {
+	my $self = shift;
+	unless ( exists $self->{_messages} ) {
+		# Cache for speed reasons
+		$self->{_messages} = [
+			sort map {
+				$_->name
+			} grep {
+				$_->isa('POE::Declare::Meta::Message')
+			} $self->attrs
+		];
+	}
+	if ( wantarray ) {
+		return @{$self->{_messages}};
+	} else {
+		return $self->{_messages};
+	}
+}
+
 1;
 
 =pod
